@@ -22,8 +22,8 @@
 G_BEGIN_DECLS
 
 /* enumerations from "./snapd-client.h" */
-GType snapd_client_error_get_type (void) G_GNUC_CONST;
-#define SNAPD_TYPE_CLIENT_ERROR (snapd_client_error_get_type())
+GType snapd_error_get_type (void) G_GNUC_CONST;
+#define SNAPD_TYPE_ERROR (snapd_error_get_type())
 
 GType snapd_find_flags_get_type (void) G_GNUC_CONST;
 #define SNAPD_TYPE_FIND_FLAGS (snapd_find_flags_get_type())
